# py-media-id-parser
A simple python package that returns the media or post ID from various social links


## Installation

```shell
pip install py-media-id-parser
```

or

```shell
pipenv install py-media-id-parser
```


## Support

- Facebook
- Twitter
- Instagram
- Youtube
- Vimeo
- Spotify


## Example

```
from media_id_parser import parse_facebook

parse_facebook('https://www.facebook.com/ESPN/posts/2415420581838017')
```
